#[non_exhaustive]pub struct PresencePromptedEventContent {
pub users: Vec<OwnedUserId>,
pub rooms: Vec<OwnedRoomId>,
}Available on crate features
events and unstable-msc4495 only.Expand description
The content of the m.presence.prompted account data key.
This uses the unstable prefix defined in MSC4495.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.users: Vec<OwnedUserId>The list of users that have previously had the presence sharing prompt displayed.
rooms: Vec<OwnedRoomId>The list of rooms that have previously had the presence sharing prompt displayed.
Implementations
Sourceimpl PresencePromptedEventContent
impl PresencePromptedEventContent
Sourcepub fn new(
users: Vec<OwnedUserId>,
rooms: Vec<OwnedRoomId>,
) -> PresencePromptedEventContent
pub fn new( users: Vec<OwnedUserId>, rooms: Vec<OwnedRoomId>, ) -> PresencePromptedEventContent
Creates a new PresencePromptedEventContent with the given users and rooms.